@@ -11,7 +11,7 @@ This is a web API wrapper works with the running "alist" server, and provide som
 from __future__ import annotations
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 0, 8)
+__version__ = (0, 0, 9)
 __all__ = ["AlistClient", "AlistPath", "AlistFileReader", "AlistFileSystem"]
 
 import errno
@@ -38,8 +38,7 @@ from aiohttp import ClientSession
 from requests import Session
 
 from .util.file import HTTPFileReader, SupportsRead, SupportsWrite
-from .util.iter import posix_glob_translate_iter
-from .util.text import complete_base_url
+from .util.text import complete_base_url, posix_glob_translate_iter
 from .util.urlopen import urlopen
 
 
@@ -1454,7 +1453,7 @@ class AlistPath(Mapping, PathLike[str]):
         )
 
     def match(self, /, path_pattern: str, ignore_case: bool = False) -> bool:
-        pattern = joinpath("/", *(t[0] for t in posix_glob_translate_iter(path_pattern)))
+        pattern = "/" + "".join(t[0] for t in posix_glob_translate_iter(path_pattern))
         if ignore_case:
             pattern = "(?i:%s)" % pattern
         return re_compile(pattern).fullmatch(self.path) is not None
@@ -1527,21 +1526,11 @@ class AlistPath(Mapping, PathLike[str]):
     def parts(self, /) -> tuple[str, ...]:
         return ("/", *self.path[1:].split("/"))
 
-    def read_bytes(self, /):
-        return self.open("rb").read()
-
-    def read_bytes_range(self, /, bytes_range="0-", headers=None) -> bytes:
-        if headers:
-            headers = {**headers, "Accept-Encoding": "identity", "Range": f"bytes={bytes_range}"}
-        else:
-            headers = {"Accept-Encoding": "identity", "Range": f"bytes={bytes_range}"}
-        with urlopen(self.url, headers=headers) as resp:
-            return resp.read()
-
-    def read_range(self, /, start=0, stop=None, headers=None) -> bytes:
+    def read_bytes(self, /, start: int = 0, stop: Optional[int] = None) -> bytes:
         length = None
         if start < 0:
-            length = urlopen(self.url).length
+            with urlopen(self.url) as resp:
+                length = cast(int, resp.length)
             start += length
         if start < 0:
             start = 0
@@ -1550,20 +1539,31 @@ class AlistPath(Mapping, PathLike[str]):
         else:
             if stop < 0:
                 if length is None:
-                    length = urlopen(self.url).length
+                    with urlopen(self.url) as resp:
+                        length = cast(int, resp.length)
                 stop += length
             if stop <= 0 or start >= stop:
                 return b""
             bytes_range = f"{start}-{stop-1}"
-        return self.read_bytes_range(bytes_range, headers=headers)
+        return self.read_bytes_range(bytes_range)
+
+    def read_bytes_range(self, /, bytes_range: str = "0-") -> bytes:
+        with urlopen(self.url, headers={"Range": f"bytes={bytes_range}"}) as resp:
+            return resp.read()
+
+    def read_block(self, /, size: int = 0, offset: int = 0) -> bytes:
+        if size <= 0:
+            return b""
+        return self.read_bytes(offset, offset + size)
 
     def read_text(
         self, 
         /, 
         encoding: Optional[str] = None, 
         errors: Optional[str] = None, 
-    ):
-        return self.open(encoding=encoding, errors=errors).read()
+        newline: Optional[str] = None, 
+    ) -> str:
+        return self.open(encoding=encoding, errors=errors, newline=newline).read()
 
     def remove(self, /, recursive: bool = False):
         return self.fs.remove(self.path, self.password, recursive=recursive, _check=False)
@@ -2306,7 +2306,7 @@ class AlistFileSystem:
         i = 0
         if ignore_case:
             if any(typ == "dstar" for _, typ, _ in splitted_pats):
-                pattern = joinpath(re_escape(dirname), *(t[0] for t in splitted_pats))
+                pattern = joinpath(re_escape(dirname), "".join(t[0] for t in splitted_pats))
                 match = re_compile("(?i:%s)" % pattern).fullmatch
                 return self.iterdir(
                     dirname, 
@@ -2328,7 +2328,7 @@ class AlistFileSystem:
             elif typ == "dstar" and i + 1 == len(splitted_pats):
                 return self.iterdir(dirname, password, max_depth=-1, _check=False)
             if any(typ == "dstar" for _, typ, _ in splitted_pats):
-                pattern = joinpath(re_escape(dirname), *(t[0] for t in splitted_pats[i:]))
+                pattern = joinpath(re_escape(dirname), "".join(t[0] for t in splitted_pats[i:]))
                 match = re_compile(pattern).fullmatch
                 return self.iterdir(
                     dirname, 
